dPGaGEV: The probability density function (PDF) of the power Garima-generalized extreme value distribution(PGaGEV).
Description
This function calculated the PDF of PGaGEV distribution.
Usage
dPGaGEV(x, mu, sigma, xi, a, b, c)
Value
the PDF of PGaGEV distribution.
Arguments
x
vector of quantiles.There are three cases as follows:
1) if xi>0, x=[(mu-sigma)/xi,Inf].2) if xi=0, x=[-Inf,Inf].3) if xi<0, x=[-Inf,(mu-sigma)/xi].
mu
location parameter.mu=[-Inf,Inf].
sigma
scale parameter number 1. sigma>0.
xi
shape parameter number 1. xi=[-Inf,Inf].
a
scale parameter number 2. a>0.
b
scale parameter number 3. b>0.
c
shape parameter number 2. c=[-Inf,Inf].
Details
The PDF of PGaGEV distribution based on the research paper in references.
References
Kittipong Klinjan, Tipat Sottiwan and Sirinapa Aryuyuen (2024).
Extreme value analysis with new generalized extreme value distributions: a case study for risk analysis on pm2.5 and pm10 in pathum thani, thailand,
Commun. Math. Biol. Neurosci. 2024, 2024:100.DOI:10.28919/cmbn/8833.