Learn R Programming

PGaGEV (version 0.1.0)

rPGaGEV: The random generating function of the power Garima-generalized extreme value distribution(PGaGEV).

Description

This function generatings random numbers of PGaGEV distribution.

Usage

rPGaGEV(n, mu, sigma, xi, a, b, c)

Value

the quantile values of PGaGEV distribution.

Arguments

n

number of observations.

mu

location parameter.mu=[-Inf,Inf].

sigma

scale parameter number 1. sigma>0.

xi

shape parameter number 1. xi=[-Inf,Inf], where xi not equal to zero.

a

scale parameter number 2. a>0.

b

scale parameter number 3. b>0.

c

shape parameter number 2. c=[-Inf,Inf].

Details

The n random value of PGaGEV distribution based on the research paper in references.

References

Kittipong Klinjan, Tipat Sottiwan and Sirinapa Aryuyuen (2024). Extreme value analysis with new generalized extreme value distributions: a case study for risk analysis on pm2.5 and pm10 in pathum thani, thailand, Commun. Math. Biol. Neurosci. 2024, 2024:100.DOI:10.28919/cmbn/8833.

Examples

Run this code
rPGaGEV(30,2,1,0.5,0.5,0.5,0.5)   #xi>0
rPGaGEV(30,2,1,-0.5,0.5,0.5,0.5)  #xi<0

Run the code above in your browser using DataLab